package betterquesting.questing;

import betterquesting.api.api.ApiReference;
import betterquesting.api.api.QuestingAPI;
import betterquesting.api.enums.EnumQuestVisibility;
import betterquesting.api.properties.IPropertyContainer;
import betterquesting.api.properties.IPropertyType;
import betterquesting.api.properties.NativeProps;
import betterquesting.api.questing.IQuestLine;
import betterquesting.api.questing.IQuestLineDatabase;
import betterquesting.api.questing.IQuestLineEntry;
import betterquesting.api.utils.BigItemStack;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.storage.SimpleDatabase;
import betterquesting.storage.PropertyContainer;
import java.util.List;
import javax.annotation.Nullable;
import net.minecraft.init.Items;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;

/* loaded from: betterquesting_questing.jar:betterquesting/questing/QuestLine.class */
public class QuestLine extends SimpleDatabase<IQuestLineEntry> implements IQuestLine {
    private IPropertyContainer info = new PropertyContainer();
    private IQuestLineDatabase parentDB = (IQuestLineDatabase) QuestingAPI.getAPI(ApiReference.LINE_DB);

    public /* bridge */ /* synthetic */ NBTBase writeToNBT(NBTBase nBTBase, @Nullable List list) {
        return writeToNBT((NBTTagCompound) nBTBase, (List<Integer>) list);
    }

    public QuestLine() {
        setupProps();
    }

    private void setupProps() {
        setupValue(NativeProps.NAME, "New Quest Line");
        setupValue(NativeProps.DESC, "No Description");
        setupValue(NativeProps.ICON, new BigItemStack(Items.field_151122_aG));
        setupValue(NativeProps.VISIBILITY, EnumQuestVisibility.NORMAL);
        setupValue(NativeProps.BG_IMAGE);
        setupValue(NativeProps.BG_SIZE);
    }

    /* JADX WARN: Multi-variable type inference failed */
    private <T> void setupValue(IPropertyType<T> prop) {
        setupValue(prop, prop.getDefault());
    }

    private <T> void setupValue(IPropertyType<T> prop, T def) {
        this.info.setProperty(prop, this.info.getProperty(prop, def));
    }

    public IQuestLineEntry createNew(int id) {
        IQuestLineEntry qle = new QuestLineEntry(0, 0, 24, 24);
        add(id, qle);
        return qle;
    }

    public String getUnlocalisedName() {
        if (!this.info.hasProperty(NativeProps.NAME)) {
            this.info.setProperty(NativeProps.NAME, "New Quest Line");
            return "New Quest Line";
        }
        return (String) this.info.getProperty(NativeProps.NAME, "New Quest Line");
    }

    public String getUnlocalisedDescription() {
        if (!this.info.hasProperty(NativeProps.DESC)) {
            this.info.setProperty(NativeProps.DESC, "No Description");
            return "No Description";
        }
        return (String) this.info.getProperty(NativeProps.DESC, "No Description");
    }

    public DBEntry<IQuestLineEntry> getEntryAt(int x, int y) {
        for (DBEntry<IQuestLineEntry> entry : getEntries()) {
            int i1 = ((IQuestLineEntry) entry.getValue()).getPosX();
            int j1 = ((IQuestLineEntry) entry.getValue()).getPosY();
            int i2 = i1 + ((IQuestLineEntry) entry.getValue()).getSizeX();
            int j2 = j1 + ((IQuestLineEntry) entry.getValue()).getSizeY();
            if (x >= i1 && x < i2 && y >= j1 && y < j2) {
                return entry;
            }
        }
        return null;
    }

    public NBTTagCompound writeToNBT(NBTTagCompound nbt) {
        return writeToNBT(nbt, (List<Integer>) null);
    }

    public void readFromNBT(NBTTagCompound nbt) {
        readFromNBT(nbt, false);
    }

    public NBTTagCompound writeToNBT(NBTTagCompound json, @Nullable List<Integer> subset) {
        json.func_74782_a("properties", this.info.writeToNBT(new NBTTagCompound()));
        NBTTagList jArr = new NBTTagList();
        for (DBEntry<IQuestLineEntry> entry : getEntries()) {
            if (subset == null || subset.contains(Integer.valueOf(entry.getID()))) {
                NBTTagCompound qle = ((IQuestLineEntry) entry.getValue()).writeToNBT(new NBTTagCompound());
                qle.func_74768_a("id", entry.getID());
                jArr.func_74742_a(qle);
            }
        }
        json.func_74782_a("quests", jArr);
        return json;
    }

    public void readFromNBT(NBTTagCompound json, boolean merge) {
        this.info.readFromNBT(json.func_74775_l("properties"));
        if (!merge) {
            reset();
        }
        NBTTagList qList = json.func_150295_c("quests", 10);
        for (int i = 0; i < qList.func_74745_c(); i++) {
            NBTTagCompound qTag = qList.func_150305_b(i);
            int id = qTag.func_150297_b("id", 99) ? qTag.func_74762_e("id") : -1;
            if (id >= 0) {
                add(id, new QuestLineEntry(qTag));
            }
        }
        setupProps();
    }

    public <T> T getProperty(IPropertyType<T> iPropertyType) {
        return (T) this.info.getProperty(iPropertyType);
    }

    public <T> T getProperty(IPropertyType<T> iPropertyType, T t) {
        return (T) this.info.getProperty(iPropertyType, t);
    }

    public boolean hasProperty(IPropertyType<?> prop) {
        return this.info.hasProperty(prop);
    }

    public <T> void setProperty(IPropertyType<T> prop, T value) {
        this.info.setProperty(prop, value);
    }

    public void removeProperty(IPropertyType<?> prop) {
        this.info.removeProperty(prop);
    }

    public void removeAllProps() {
        this.info.removeAllProps();
    }
}
